# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..client.configuration import Configuration
from ..client.api_client import ApiClient


class RolesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_role(self, role, account_id, **kwargs):
        """
        Creates a role.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_role(role, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RoleForCreate role:  (required)
        :param str account_id: (required)
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_role_with_http_info(role, account_id, **kwargs)
        else:
            (data) = self.create_role_with_http_info(role, account_id, **kwargs)
            return data

    def create_role_with_http_info(self, role, account_id, **kwargs):
        """
        Creates a role.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_role_with_http_info(role, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RoleForCreate role:  (required)
        :param str account_id: (required)
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'role' is set
        if ('role' not in params) or (params['role'] is None):
            raise ValueError("Missing the required parameter `role` when calling `create_role`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `create_role`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'role' in params:
            body_params = params['role']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Role',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_role(self, role_id, account_id, **kwargs):
        """
        Deletes the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_role(role_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_role_with_http_info(role_id, account_id, **kwargs)
        else:
            (data) = self.delete_role_with_http_info(role_id, account_id, **kwargs)
            return data

    def delete_role_with_http_info(self, role_id, account_id, **kwargs):
        """
        Deletes the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_role_with_http_info(role_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `delete_role`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `delete_role`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_role(self, role_id, account_id, **kwargs):
        """
        Get information about the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_role(role_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param str account_id: (required)
        :param bool include_is_assigned: 
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_role_with_http_info(role_id, account_id, **kwargs)
        else:
            (data) = self.get_role_with_http_info(role_id, account_id, **kwargs)
            return data

    def get_role_with_http_info(self, role_id, account_id, **kwargs):
        """
        Get information about the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_role_with_http_info(role_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param str account_id: (required)
        :param bool include_is_assigned: 
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'account_id', 'include_is_assigned']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `get_role`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_role`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'include_is_assigned' in params:
            query_params['includeIsAssigned'] = params['include_is_assigned']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Role',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_roles(self, account_id, **kwargs):
        """
        Gets a paged-list of roles in your company
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_roles(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param bool only_assignable: 
        :param str filter: 
        :param int start_position: 
        :param int count: 
        :return: RoleSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_roles_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_roles_with_http_info(account_id, **kwargs)
            return data

    def get_roles_with_http_info(self, account_id, **kwargs):
        """
        Gets a paged-list of roles in your company
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_roles_with_http_info(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param bool only_assignable: 
        :param str filter: 
        :param int start_position: 
        :param int count: 
        :return: RoleSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'only_assignable', 'filter', 'start_position', 'count']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_roles`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'only_assignable' in params:
            query_params['onlyAssignable'] = params['only_assignable']
        if 'filter' in params:
            query_params['filter'] = params['filter']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']
        if 'count' in params:
            query_params['count'] = params['count']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoleSummaryList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_role(self, role_id, role, account_id, **kwargs):
        """
        Updates the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_role(role_id, role, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param RoleForUpdate role:  (required)
        :param str account_id: (required)
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_role_with_http_info(role_id, role, account_id, **kwargs)
        else:
            (data) = self.update_role_with_http_info(role_id, role, account_id, **kwargs)
            return data

    def update_role_with_http_info(self, role_id, role, account_id, **kwargs):
        """
        Updates the role with the given roleId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_role_with_http_info(role_id, role, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int role_id:  (required)
        :param RoleForUpdate role:  (required)
        :param str account_id: (required)
        :return: Role
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_id', 'role', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'role_id' is set
        if ('role_id' not in params) or (params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `update_role`")
        # verify the required parameter 'role' is set
        if ('role' not in params) or (params['role'] is None):
            raise ValueError("Missing the required parameter `role` when calling `update_role`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `update_role`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/roles/{roleId}'.replace('{format}', 'json')
        path_params = {}
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'role' in params:
            body_params = params['role']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Role',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    DocuSign REST API

    The DocuSign REST API provides you with a powerful, convenient, and simple Web services API for interacting with DocuSign.

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """
        Custom error messages for exception
        """
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


class ArgumentException(Exception):

    def __init__(self, *args, **kwargs):
        if not args:
            super(Exception).__init__("argument cannot be empty")
        else:
            super(Exception).__init__(*args, **kwargs)


class InvalidBasePath(Exception):
    pass



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaskListSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_list_id': 'int',
        'name': 'str',
        'task_list_template_id': 'int',
        'submitted_for_review_date': 'datetime',
        'approval_date': 'datetime',
        'rejected_date': 'datetime',
        'created_date': 'datetime',
        'approved_by_user_id': 'int',
        'rejected_by_user_id': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'task_list_id': 'taskListId',
        'name': 'name',
        'task_list_template_id': 'taskListTemplateId',
        'submitted_for_review_date': 'submittedForReviewDate',
        'approval_date': 'approvalDate',
        'rejected_date': 'rejectedDate',
        'created_date': 'createdDate',
        'approved_by_user_id': 'approvedByUserId',
        'rejected_by_user_id': 'rejectedByUserId',
        'comment': 'comment'
    }

    def __init__(self, task_list_id=None, name=None, task_list_template_id=None, submitted_for_review_date=None, approval_date=None, rejected_date=None, created_date=None, approved_by_user_id=None, rejected_by_user_id=None, comment=None):  # noqa: E501
        """TaskListSummary - a model defined in Swagger"""  # noqa: E501

        self._task_list_id = None
        self._name = None
        self._task_list_template_id = None
        self._submitted_for_review_date = None
        self._approval_date = None
        self._rejected_date = None
        self._created_date = None
        self._approved_by_user_id = None
        self._rejected_by_user_id = None
        self._comment = None
        self.discriminator = None

        if task_list_id is not None:
            self.task_list_id = task_list_id
        if name is not None:
            self.name = name
        if task_list_template_id is not None:
            self.task_list_template_id = task_list_template_id
        if submitted_for_review_date is not None:
            self.submitted_for_review_date = submitted_for_review_date
        if approval_date is not None:
            self.approval_date = approval_date
        if rejected_date is not None:
            self.rejected_date = rejected_date
        if created_date is not None:
            self.created_date = created_date
        if approved_by_user_id is not None:
            self.approved_by_user_id = approved_by_user_id
        if rejected_by_user_id is not None:
            self.rejected_by_user_id = rejected_by_user_id
        if comment is not None:
            self.comment = comment

    @property
    def task_list_id(self):
        """Gets the task_list_id of this TaskListSummary.  # noqa: E501


        :return: The task_list_id of this TaskListSummary.  # noqa: E501
        :rtype: int
        """
        return self._task_list_id

    @task_list_id.setter
    def task_list_id(self, task_list_id):
        """Sets the task_list_id of this TaskListSummary.


        :param task_list_id: The task_list_id of this TaskListSummary.  # noqa: E501
        :type: int
        """

        self._task_list_id = task_list_id

    @property
    def name(self):
        """Gets the name of this TaskListSummary.  # noqa: E501


        :return: The name of this TaskListSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskListSummary.


        :param name: The name of this TaskListSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def task_list_template_id(self):
        """Gets the task_list_template_id of this TaskListSummary.  # noqa: E501


        :return: The task_list_template_id of this TaskListSummary.  # noqa: E501
        :rtype: int
        """
        return self._task_list_template_id

    @task_list_template_id.setter
    def task_list_template_id(self, task_list_template_id):
        """Sets the task_list_template_id of this TaskListSummary.


        :param task_list_template_id: The task_list_template_id of this TaskListSummary.  # noqa: E501
        :type: int
        """

        self._task_list_template_id = task_list_template_id

    @property
    def submitted_for_review_date(self):
        """Gets the submitted_for_review_date of this TaskListSummary.  # noqa: E501


        :return: The submitted_for_review_date of this TaskListSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._submitted_for_review_date

    @submitted_for_review_date.setter
    def submitted_for_review_date(self, submitted_for_review_date):
        """Sets the submitted_for_review_date of this TaskListSummary.


        :param submitted_for_review_date: The submitted_for_review_date of this TaskListSummary.  # noqa: E501
        :type: datetime
        """

        self._submitted_for_review_date = submitted_for_review_date

    @property
    def approval_date(self):
        """Gets the approval_date of this TaskListSummary.  # noqa: E501


        :return: The approval_date of this TaskListSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._approval_date

    @approval_date.setter
    def approval_date(self, approval_date):
        """Sets the approval_date of this TaskListSummary.


        :param approval_date: The approval_date of this TaskListSummary.  # noqa: E501
        :type: datetime
        """

        self._approval_date = approval_date

    @property
    def rejected_date(self):
        """Gets the rejected_date of this TaskListSummary.  # noqa: E501


        :return: The rejected_date of this TaskListSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._rejected_date

    @rejected_date.setter
    def rejected_date(self, rejected_date):
        """Sets the rejected_date of this TaskListSummary.


        :param rejected_date: The rejected_date of this TaskListSummary.  # noqa: E501
        :type: datetime
        """

        self._rejected_date = rejected_date

    @property
    def created_date(self):
        """Gets the created_date of this TaskListSummary.  # noqa: E501


        :return: The created_date of this TaskListSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this TaskListSummary.


        :param created_date: The created_date of this TaskListSummary.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def approved_by_user_id(self):
        """Gets the approved_by_user_id of this TaskListSummary.  # noqa: E501


        :return: The approved_by_user_id of this TaskListSummary.  # noqa: E501
        :rtype: int
        """
        return self._approved_by_user_id

    @approved_by_user_id.setter
    def approved_by_user_id(self, approved_by_user_id):
        """Sets the approved_by_user_id of this TaskListSummary.


        :param approved_by_user_id: The approved_by_user_id of this TaskListSummary.  # noqa: E501
        :type: int
        """

        self._approved_by_user_id = approved_by_user_id

    @property
    def rejected_by_user_id(self):
        """Gets the rejected_by_user_id of this TaskListSummary.  # noqa: E501


        :return: The rejected_by_user_id of this TaskListSummary.  # noqa: E501
        :rtype: int
        """
        return self._rejected_by_user_id

    @rejected_by_user_id.setter
    def rejected_by_user_id(self, rejected_by_user_id):
        """Sets the rejected_by_user_id of this TaskListSummary.


        :param rejected_by_user_id: The rejected_by_user_id of this TaskListSummary.  # noqa: E501
        :type: int
        """

        self._rejected_by_user_id = rejected_by_user_id

    @property
    def comment(self):
        """Gets the comment of this TaskListSummary.  # noqa: E501


        :return: The comment of this TaskListSummary.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this TaskListSummary.


        :param comment: The comment of this TaskListSummary.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskListSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskListSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Permissions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_add_users_to_rooms': 'bool',
        'can_create_rooms': 'bool',
        'can_submit_rooms_for_review': 'bool',
        'can_close_rooms': 'bool',
        'can_reopen_rooms': 'bool',
        'can_delete_owned_rooms': 'bool',
        'auto_access_to_rooms': 'bool',
        'can_export_room_activity_details_people': 'bool',
        'is_visible_in_rooms': 'bool',
        'can_copy_room_details': 'bool',
        'can_edit_any_room_role': 'bool',
        'can_edit_invited_room_role': 'bool',
        'can_manage_any_user_room_access': 'bool',
        'can_manage_invited_user_room_access': 'bool',
        'can_view_room_details': 'bool',
        'can_view_and_edit_room_details': 'bool',
        'can_send_room_details_to_lone_wolf': 'bool',
        'can_add_documents': 'bool',
        'can_add_documents_from_form_groups': 'bool',
        'can_add_documents_from_form_libraries': 'bool',
        'documents_viewable_by_others_in_room_from_office': 'bool',
        'documents_auto_owned_by_peers': 'bool',
        'can_delete_owned_documents': 'bool',
        'can_manage_shared_docs': 'bool',
        'can_manage_form_groups': 'bool',
        'can_share_docs_not_owned': 'bool',
        'can_add_tasks_to_any_task_lists': 'bool',
        'can_edit_editable_tasks': 'bool',
        'can_edit_any_tasks': 'bool',
        'can_delete_deletable_tasks': 'bool',
        'can_delete_any_tasks': 'bool',
        'can_apply_task_list': 'bool',
        'can_remove_any_task_list': 'bool',
        'can_submit_task_list': 'bool',
        'can_auto_submit_task_list': 'bool',
        'can_review_task_list': 'bool',
        'can_auto_approve_task_list': 'bool',
        'can_manage_task_templates_for_all_regions_all_offices': 'bool',
        'can_apply_room_templates': 'bool',
        'can_add_tasks_to_rooms': 'bool',
        'can_create_and_manage_packages': 'bool',
        'can_add_member_and_set_role_lower_access_level': 'bool',
        'can_add_member_and_set_role_same_access_level': 'bool',
        'can_change_member_role_lower_access_level': 'bool',
        'can_change_member_role_same_access_level': 'bool',
        'can_manage_member_lower_access_level': 'bool',
        'can_manage_member_same_access_level': 'bool',
        'can_remove_company_member_lower_access_level': 'bool',
        'can_remove_company_member_same_access_level': 'bool',
        'can_manage_account': 'bool',
        'can_manage_logo': 'bool',
        'can_manage_room_details': 'bool',
        'can_manage_room_templates': 'bool',
        'can_manage_integration_settings': 'bool'
    }

    attribute_map = {
        'can_add_users_to_rooms': 'canAddUsersToRooms',
        'can_create_rooms': 'canCreateRooms',
        'can_submit_rooms_for_review': 'canSubmitRoomsForReview',
        'can_close_rooms': 'canCloseRooms',
        'can_reopen_rooms': 'canReopenRooms',
        'can_delete_owned_rooms': 'canDeleteOwnedRooms',
        'auto_access_to_rooms': 'autoAccessToRooms',
        'can_export_room_activity_details_people': 'canExportRoomActivityDetailsPeople',
        'is_visible_in_rooms': 'isVisibleInRooms',
        'can_copy_room_details': 'canCopyRoomDetails',
        'can_edit_any_room_role': 'canEditAnyRoomRole',
        'can_edit_invited_room_role': 'canEditInvitedRoomRole',
        'can_manage_any_user_room_access': 'canManageAnyUserRoomAccess',
        'can_manage_invited_user_room_access': 'canManageInvitedUserRoomAccess',
        'can_view_room_details': 'canViewRoomDetails',
        'can_view_and_edit_room_details': 'canViewAndEditRoomDetails',
        'can_send_room_details_to_lone_wolf': 'canSendRoomDetailsToLoneWolf',
        'can_add_documents': 'canAddDocuments',
        'can_add_documents_from_form_groups': 'canAddDocumentsFromFormGroups',
        'can_add_documents_from_form_libraries': 'canAddDocumentsFromFormLibraries',
        'documents_viewable_by_others_in_room_from_office': 'documentsViewableByOthersInRoomFromOffice',
        'documents_auto_owned_by_peers': 'documentsAutoOwnedByPeers',
        'can_delete_owned_documents': 'canDeleteOwnedDocuments',
        'can_manage_shared_docs': 'canManageSharedDocs',
        'can_manage_form_groups': 'canManageFormGroups',
        'can_share_docs_not_owned': 'canShareDocsNotOwned',
        'can_add_tasks_to_any_task_lists': 'canAddTasksToAnyTaskLists',
        'can_edit_editable_tasks': 'canEditEditableTasks',
        'can_edit_any_tasks': 'canEditAnyTasks',
        'can_delete_deletable_tasks': 'canDeleteDeletableTasks',
        'can_delete_any_tasks': 'canDeleteAnyTasks',
        'can_apply_task_list': 'canApplyTaskList',
        'can_remove_any_task_list': 'canRemoveAnyTaskList',
        'can_submit_task_list': 'canSubmitTaskList',
        'can_auto_submit_task_list': 'canAutoSubmitTaskList',
        'can_review_task_list': 'canReviewTaskList',
        'can_auto_approve_task_list': 'canAutoApproveTaskList',
        'can_manage_task_templates_for_all_regions_all_offices': 'canManageTaskTemplatesForAllRegionsAllOffices',
        'can_apply_room_templates': 'canApplyRoomTemplates',
        'can_add_tasks_to_rooms': 'canAddTasksToRooms',
        'can_create_and_manage_packages': 'canCreateAndManagePackages',
        'can_add_member_and_set_role_lower_access_level': 'canAddMemberAndSetRoleLowerAccessLevel',
        'can_add_member_and_set_role_same_access_level': 'canAddMemberAndSetRoleSameAccessLevel',
        'can_change_member_role_lower_access_level': 'canChangeMemberRoleLowerAccessLevel',
        'can_change_member_role_same_access_level': 'canChangeMemberRoleSameAccessLevel',
        'can_manage_member_lower_access_level': 'canManageMemberLowerAccessLevel',
        'can_manage_member_same_access_level': 'canManageMemberSameAccessLevel',
        'can_remove_company_member_lower_access_level': 'canRemoveCompanyMemberLowerAccessLevel',
        'can_remove_company_member_same_access_level': 'canRemoveCompanyMemberSameAccessLevel',
        'can_manage_account': 'canManageAccount',
        'can_manage_logo': 'canManageLogo',
        'can_manage_room_details': 'canManageRoomDetails',
        'can_manage_room_templates': 'canManageRoomTemplates',
        'can_manage_integration_settings': 'canManageIntegrationSettings'
    }

    def __init__(self, can_add_users_to_rooms=None, can_create_rooms=None, can_submit_rooms_for_review=None, can_close_rooms=None, can_reopen_rooms=None, can_delete_owned_rooms=None, auto_access_to_rooms=None, can_export_room_activity_details_people=None, is_visible_in_rooms=None, can_copy_room_details=None, can_edit_any_room_role=None, can_edit_invited_room_role=None, can_manage_any_user_room_access=None, can_manage_invited_user_room_access=None, can_view_room_details=None, can_view_and_edit_room_details=None, can_send_room_details_to_lone_wolf=None, can_add_documents=None, can_add_documents_from_form_groups=None, can_add_documents_from_form_libraries=None, documents_viewable_by_others_in_room_from_office=None, documents_auto_owned_by_peers=None, can_delete_owned_documents=None, can_manage_shared_docs=None, can_manage_form_groups=None, can_share_docs_not_owned=None, can_add_tasks_to_any_task_lists=None, can_edit_editable_tasks=None, can_edit_any_tasks=None, can_delete_deletable_tasks=None, can_delete_any_tasks=None, can_apply_task_list=None, can_remove_any_task_list=None, can_submit_task_list=None, can_auto_submit_task_list=None, can_review_task_list=None, can_auto_approve_task_list=None, can_manage_task_templates_for_all_regions_all_offices=None, can_apply_room_templates=None, can_add_tasks_to_rooms=None, can_create_and_manage_packages=None, can_add_member_and_set_role_lower_access_level=None, can_add_member_and_set_role_same_access_level=None, can_change_member_role_lower_access_level=None, can_change_member_role_same_access_level=None, can_manage_member_lower_access_level=None, can_manage_member_same_access_level=None, can_remove_company_member_lower_access_level=None, can_remove_company_member_same_access_level=None, can_manage_account=None, can_manage_logo=None, can_manage_room_details=None, can_manage_room_templates=None, can_manage_integration_settings=None):  # noqa: E501
        """Permissions - a model defined in Swagger"""  # noqa: E501

        self._can_add_users_to_rooms = None
        self._can_create_rooms = None
        self._can_submit_rooms_for_review = None
        self._can_close_rooms = None
        self._can_reopen_rooms = None
        self._can_delete_owned_rooms = None
        self._auto_access_to_rooms = None
        self._can_export_room_activity_details_people = None
        self._is_visible_in_rooms = None
        self._can_copy_room_details = None
        self._can_edit_any_room_role = None
        self._can_edit_invited_room_role = None
        self._can_manage_any_user_room_access = None
        self._can_manage_invited_user_room_access = None
        self._can_view_room_details = None
        self._can_view_and_edit_room_details = None
        self._can_send_room_details_to_lone_wolf = None
        self._can_add_documents = None
        self._can_add_documents_from_form_groups = None
        self._can_add_documents_from_form_libraries = None
        self._documents_viewable_by_others_in_room_from_office = None
        self._documents_auto_owned_by_peers = None
        self._can_delete_owned_documents = None
        self._can_manage_shared_docs = None
        self._can_manage_form_groups = None
        self._can_share_docs_not_owned = None
        self._can_add_tasks_to_any_task_lists = None
        self._can_edit_editable_tasks = None
        self._can_edit_any_tasks = None
        self._can_delete_deletable_tasks = None
        self._can_delete_any_tasks = None
        self._can_apply_task_list = None
        self._can_remove_any_task_list = None
        self._can_submit_task_list = None
        self._can_auto_submit_task_list = None
        self._can_review_task_list = None
        self._can_auto_approve_task_list = None
        self._can_manage_task_templates_for_all_regions_all_offices = None
        self._can_apply_room_templates = None
        self._can_add_tasks_to_rooms = None
        self._can_create_and_manage_packages = None
        self._can_add_member_and_set_role_lower_access_level = None
        self._can_add_member_and_set_role_same_access_level = None
        self._can_change_member_role_lower_access_level = None
        self._can_change_member_role_same_access_level = None
        self._can_manage_member_lower_access_level = None
        self._can_manage_member_same_access_level = None
        self._can_remove_company_member_lower_access_level = None
        self._can_remove_company_member_same_access_level = None
        self._can_manage_account = None
        self._can_manage_logo = None
        self._can_manage_room_details = None
        self._can_manage_room_templates = None
        self._can_manage_integration_settings = None
        self.discriminator = None

        if can_add_users_to_rooms is not None:
            self.can_add_users_to_rooms = can_add_users_to_rooms
        if can_create_rooms is not None:
            self.can_create_rooms = can_create_rooms
        if can_submit_rooms_for_review is not None:
            self.can_submit_rooms_for_review = can_submit_rooms_for_review
        if can_close_rooms is not None:
            self.can_close_rooms = can_close_rooms
        if can_reopen_rooms is not None:
            self.can_reopen_rooms = can_reopen_rooms
        if can_delete_owned_rooms is not None:
            self.can_delete_owned_rooms = can_delete_owned_rooms
        if auto_access_to_rooms is not None:
            self.auto_access_to_rooms = auto_access_to_rooms
        if can_export_room_activity_details_people is not None:
            self.can_export_room_activity_details_people = can_export_room_activity_details_people
        if is_visible_in_rooms is not None:
            self.is_visible_in_rooms = is_visible_in_rooms
        if can_copy_room_details is not None:
            self.can_copy_room_details = can_copy_room_details
        if can_edit_any_room_role is not None:
            self.can_edit_any_room_role = can_edit_any_room_role
        if can_edit_invited_room_role is not None:
            self.can_edit_invited_room_role = can_edit_invited_room_role
        if can_manage_any_user_room_access is not None:
            self.can_manage_any_user_room_access = can_manage_any_user_room_access
        if can_manage_invited_user_room_access is not None:
            self.can_manage_invited_user_room_access = can_manage_invited_user_room_access
        if can_view_room_details is not None:
            self.can_view_room_details = can_view_room_details
        if can_view_and_edit_room_details is not None:
            self.can_view_and_edit_room_details = can_view_and_edit_room_details
        if can_send_room_details_to_lone_wolf is not None:
            self.can_send_room_details_to_lone_wolf = can_send_room_details_to_lone_wolf
        if can_add_documents is not None:
            self.can_add_documents = can_add_documents
        if can_add_documents_from_form_groups is not None:
            self.can_add_documents_from_form_groups = can_add_documents_from_form_groups
        if can_add_documents_from_form_libraries is not None:
            self.can_add_documents_from_form_libraries = can_add_documents_from_form_libraries
        if documents_viewable_by_others_in_room_from_office is not None:
            self.documents_viewable_by_others_in_room_from_office = documents_viewable_by_others_in_room_from_office
        if documents_auto_owned_by_peers is not None:
            self.documents_auto_owned_by_peers = documents_auto_owned_by_peers
        if can_delete_owned_documents is not None:
            self.can_delete_owned_documents = can_delete_owned_documents
        if can_manage_shared_docs is not None:
            self.can_manage_shared_docs = can_manage_shared_docs
        if can_manage_form_groups is not None:
            self.can_manage_form_groups = can_manage_form_groups
        if can_share_docs_not_owned is not None:
            self.can_share_docs_not_owned = can_share_docs_not_owned
        if can_add_tasks_to_any_task_lists is not None:
            self.can_add_tasks_to_any_task_lists = can_add_tasks_to_any_task_lists
        if can_edit_editable_tasks is not None:
            self.can_edit_editable_tasks = can_edit_editable_tasks
        if can_edit_any_tasks is not None:
            self.can_edit_any_tasks = can_edit_any_tasks
        if can_delete_deletable_tasks is not None:
            self.can_delete_deletable_tasks = can_delete_deletable_tasks
        if can_delete_any_tasks is not None:
            self.can_delete_any_tasks = can_delete_any_tasks
        if can_apply_task_list is not None:
            self.can_apply_task_list = can_apply_task_list
        if can_remove_any_task_list is not None:
            self.can_remove_any_task_list = can_remove_any_task_list
        if can_submit_task_list is not None:
            self.can_submit_task_list = can_submit_task_list
        if can_auto_submit_task_list is not None:
            self.can_auto_submit_task_list = can_auto_submit_task_list
        if can_review_task_list is not None:
            self.can_review_task_list = can_review_task_list
        if can_auto_approve_task_list is not None:
            self.can_auto_approve_task_list = can_auto_approve_task_list
        if can_manage_task_templates_for_all_regions_all_offices is not None:
            self.can_manage_task_templates_for_all_regions_all_offices = can_manage_task_templates_for_all_regions_all_offices
        if can_apply_room_templates is not None:
            self.can_apply_room_templates = can_apply_room_templates
        if can_add_tasks_to_rooms is not None:
            self.can_add_tasks_to_rooms = can_add_tasks_to_rooms
        if can_create_and_manage_packages is not None:
            self.can_create_and_manage_packages = can_create_and_manage_packages
        if can_add_member_and_set_role_lower_access_level is not None:
            self.can_add_member_and_set_role_lower_access_level = can_add_member_and_set_role_lower_access_level
        if can_add_member_and_set_role_same_access_level is not None:
            self.can_add_member_and_set_role_same_access_level = can_add_member_and_set_role_same_access_level
        if can_change_member_role_lower_access_level is not None:
            self.can_change_member_role_lower_access_level = can_change_member_role_lower_access_level
        if can_change_member_role_same_access_level is not None:
            self.can_change_member_role_same_access_level = can_change_member_role_same_access_level
        if can_manage_member_lower_access_level is not None:
            self.can_manage_member_lower_access_level = can_manage_member_lower_access_level
        if can_manage_member_same_access_level is not None:
            self.can_manage_member_same_access_level = can_manage_member_same_access_level
        if can_remove_company_member_lower_access_level is not None:
            self.can_remove_company_member_lower_access_level = can_remove_company_member_lower_access_level
        if can_remove_company_member_same_access_level is not None:
            self.can_remove_company_member_same_access_level = can_remove_company_member_same_access_level
        if can_manage_account is not None:
            self.can_manage_account = can_manage_account
        if can_manage_logo is not None:
            self.can_manage_logo = can_manage_logo
        if can_manage_room_details is not None:
            self.can_manage_room_details = can_manage_room_details
        if can_manage_room_templates is not None:
            self.can_manage_room_templates = can_manage_room_templates
        if can_manage_integration_settings is not None:
            self.can_manage_integration_settings = can_manage_integration_settings

    @property
    def can_add_users_to_rooms(self):
        """Gets the can_add_users_to_rooms of this Permissions.  # noqa: E501


        :return: The can_add_users_to_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_users_to_rooms

    @can_add_users_to_rooms.setter
    def can_add_users_to_rooms(self, can_add_users_to_rooms):
        """Sets the can_add_users_to_rooms of this Permissions.


        :param can_add_users_to_rooms: The can_add_users_to_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_users_to_rooms = can_add_users_to_rooms

    @property
    def can_create_rooms(self):
        """Gets the can_create_rooms of this Permissions.  # noqa: E501


        :return: The can_create_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_create_rooms

    @can_create_rooms.setter
    def can_create_rooms(self, can_create_rooms):
        """Sets the can_create_rooms of this Permissions.


        :param can_create_rooms: The can_create_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_create_rooms = can_create_rooms

    @property
    def can_submit_rooms_for_review(self):
        """Gets the can_submit_rooms_for_review of this Permissions.  # noqa: E501


        :return: The can_submit_rooms_for_review of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_submit_rooms_for_review

    @can_submit_rooms_for_review.setter
    def can_submit_rooms_for_review(self, can_submit_rooms_for_review):
        """Sets the can_submit_rooms_for_review of this Permissions.


        :param can_submit_rooms_for_review: The can_submit_rooms_for_review of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_submit_rooms_for_review = can_submit_rooms_for_review

    @property
    def can_close_rooms(self):
        """Gets the can_close_rooms of this Permissions.  # noqa: E501


        :return: The can_close_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_close_rooms

    @can_close_rooms.setter
    def can_close_rooms(self, can_close_rooms):
        """Sets the can_close_rooms of this Permissions.


        :param can_close_rooms: The can_close_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_close_rooms = can_close_rooms

    @property
    def can_reopen_rooms(self):
        """Gets the can_reopen_rooms of this Permissions.  # noqa: E501


        :return: The can_reopen_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_reopen_rooms

    @can_reopen_rooms.setter
    def can_reopen_rooms(self, can_reopen_rooms):
        """Sets the can_reopen_rooms of this Permissions.


        :param can_reopen_rooms: The can_reopen_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_reopen_rooms = can_reopen_rooms

    @property
    def can_delete_owned_rooms(self):
        """Gets the can_delete_owned_rooms of this Permissions.  # noqa: E501


        :return: The can_delete_owned_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_owned_rooms

    @can_delete_owned_rooms.setter
    def can_delete_owned_rooms(self, can_delete_owned_rooms):
        """Sets the can_delete_owned_rooms of this Permissions.


        :param can_delete_owned_rooms: The can_delete_owned_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_owned_rooms = can_delete_owned_rooms

    @property
    def auto_access_to_rooms(self):
        """Gets the auto_access_to_rooms of this Permissions.  # noqa: E501


        :return: The auto_access_to_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._auto_access_to_rooms

    @auto_access_to_rooms.setter
    def auto_access_to_rooms(self, auto_access_to_rooms):
        """Sets the auto_access_to_rooms of this Permissions.


        :param auto_access_to_rooms: The auto_access_to_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._auto_access_to_rooms = auto_access_to_rooms

    @property
    def can_export_room_activity_details_people(self):
        """Gets the can_export_room_activity_details_people of this Permissions.  # noqa: E501


        :return: The can_export_room_activity_details_people of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_export_room_activity_details_people

    @can_export_room_activity_details_people.setter
    def can_export_room_activity_details_people(self, can_export_room_activity_details_people):
        """Sets the can_export_room_activity_details_people of this Permissions.


        :param can_export_room_activity_details_people: The can_export_room_activity_details_people of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_export_room_activity_details_people = can_export_room_activity_details_people

    @property
    def is_visible_in_rooms(self):
        """Gets the is_visible_in_rooms of this Permissions.  # noqa: E501


        :return: The is_visible_in_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible_in_rooms

    @is_visible_in_rooms.setter
    def is_visible_in_rooms(self, is_visible_in_rooms):
        """Sets the is_visible_in_rooms of this Permissions.


        :param is_visible_in_rooms: The is_visible_in_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._is_visible_in_rooms = is_visible_in_rooms

    @property
    def can_copy_room_details(self):
        """Gets the can_copy_room_details of this Permissions.  # noqa: E501


        :return: The can_copy_room_details of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_copy_room_details

    @can_copy_room_details.setter
    def can_copy_room_details(self, can_copy_room_details):
        """Sets the can_copy_room_details of this Permissions.


        :param can_copy_room_details: The can_copy_room_details of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_copy_room_details = can_copy_room_details

    @property
    def can_edit_any_room_role(self):
        """Gets the can_edit_any_room_role of this Permissions.  # noqa: E501


        :return: The can_edit_any_room_role of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit_any_room_role

    @can_edit_any_room_role.setter
    def can_edit_any_room_role(self, can_edit_any_room_role):
        """Sets the can_edit_any_room_role of this Permissions.


        :param can_edit_any_room_role: The can_edit_any_room_role of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_edit_any_room_role = can_edit_any_room_role

    @property
    def can_edit_invited_room_role(self):
        """Gets the can_edit_invited_room_role of this Permissions.  # noqa: E501


        :return: The can_edit_invited_room_role of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit_invited_room_role

    @can_edit_invited_room_role.setter
    def can_edit_invited_room_role(self, can_edit_invited_room_role):
        """Sets the can_edit_invited_room_role of this Permissions.


        :param can_edit_invited_room_role: The can_edit_invited_room_role of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_edit_invited_room_role = can_edit_invited_room_role

    @property
    def can_manage_any_user_room_access(self):
        """Gets the can_manage_any_user_room_access of this Permissions.  # noqa: E501


        :return: The can_manage_any_user_room_access of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_any_user_room_access

    @can_manage_any_user_room_access.setter
    def can_manage_any_user_room_access(self, can_manage_any_user_room_access):
        """Sets the can_manage_any_user_room_access of this Permissions.


        :param can_manage_any_user_room_access: The can_manage_any_user_room_access of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_any_user_room_access = can_manage_any_user_room_access

    @property
    def can_manage_invited_user_room_access(self):
        """Gets the can_manage_invited_user_room_access of this Permissions.  # noqa: E501


        :return: The can_manage_invited_user_room_access of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_invited_user_room_access

    @can_manage_invited_user_room_access.setter
    def can_manage_invited_user_room_access(self, can_manage_invited_user_room_access):
        """Sets the can_manage_invited_user_room_access of this Permissions.


        :param can_manage_invited_user_room_access: The can_manage_invited_user_room_access of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_invited_user_room_access = can_manage_invited_user_room_access

    @property
    def can_view_room_details(self):
        """Gets the can_view_room_details of this Permissions.  # noqa: E501


        :return: The can_view_room_details of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_view_room_details

    @can_view_room_details.setter
    def can_view_room_details(self, can_view_room_details):
        """Sets the can_view_room_details of this Permissions.


        :param can_view_room_details: The can_view_room_details of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_view_room_details = can_view_room_details

    @property
    def can_view_and_edit_room_details(self):
        """Gets the can_view_and_edit_room_details of this Permissions.  # noqa: E501


        :return: The can_view_and_edit_room_details of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_view_and_edit_room_details

    @can_view_and_edit_room_details.setter
    def can_view_and_edit_room_details(self, can_view_and_edit_room_details):
        """Sets the can_view_and_edit_room_details of this Permissions.


        :param can_view_and_edit_room_details: The can_view_and_edit_room_details of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_view_and_edit_room_details = can_view_and_edit_room_details

    @property
    def can_send_room_details_to_lone_wolf(self):
        """Gets the can_send_room_details_to_lone_wolf of this Permissions.  # noqa: E501


        :return: The can_send_room_details_to_lone_wolf of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_send_room_details_to_lone_wolf

    @can_send_room_details_to_lone_wolf.setter
    def can_send_room_details_to_lone_wolf(self, can_send_room_details_to_lone_wolf):
        """Sets the can_send_room_details_to_lone_wolf of this Permissions.


        :param can_send_room_details_to_lone_wolf: The can_send_room_details_to_lone_wolf of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_send_room_details_to_lone_wolf = can_send_room_details_to_lone_wolf

    @property
    def can_add_documents(self):
        """Gets the can_add_documents of this Permissions.  # noqa: E501


        :return: The can_add_documents of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_documents

    @can_add_documents.setter
    def can_add_documents(self, can_add_documents):
        """Sets the can_add_documents of this Permissions.


        :param can_add_documents: The can_add_documents of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_documents = can_add_documents

    @property
    def can_add_documents_from_form_groups(self):
        """Gets the can_add_documents_from_form_groups of this Permissions.  # noqa: E501


        :return: The can_add_documents_from_form_groups of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_documents_from_form_groups

    @can_add_documents_from_form_groups.setter
    def can_add_documents_from_form_groups(self, can_add_documents_from_form_groups):
        """Sets the can_add_documents_from_form_groups of this Permissions.


        :param can_add_documents_from_form_groups: The can_add_documents_from_form_groups of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_documents_from_form_groups = can_add_documents_from_form_groups

    @property
    def can_add_documents_from_form_libraries(self):
        """Gets the can_add_documents_from_form_libraries of this Permissions.  # noqa: E501


        :return: The can_add_documents_from_form_libraries of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_documents_from_form_libraries

    @can_add_documents_from_form_libraries.setter
    def can_add_documents_from_form_libraries(self, can_add_documents_from_form_libraries):
        """Sets the can_add_documents_from_form_libraries of this Permissions.


        :param can_add_documents_from_form_libraries: The can_add_documents_from_form_libraries of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_documents_from_form_libraries = can_add_documents_from_form_libraries

    @property
    def documents_viewable_by_others_in_room_from_office(self):
        """Gets the documents_viewable_by_others_in_room_from_office of this Permissions.  # noqa: E501


        :return: The documents_viewable_by_others_in_room_from_office of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._documents_viewable_by_others_in_room_from_office

    @documents_viewable_by_others_in_room_from_office.setter
    def documents_viewable_by_others_in_room_from_office(self, documents_viewable_by_others_in_room_from_office):
        """Sets the documents_viewable_by_others_in_room_from_office of this Permissions.


        :param documents_viewable_by_others_in_room_from_office: The documents_viewable_by_others_in_room_from_office of this Permissions.  # noqa: E501
        :type: bool
        """

        self._documents_viewable_by_others_in_room_from_office = documents_viewable_by_others_in_room_from_office

    @property
    def documents_auto_owned_by_peers(self):
        """Gets the documents_auto_owned_by_peers of this Permissions.  # noqa: E501


        :return: The documents_auto_owned_by_peers of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._documents_auto_owned_by_peers

    @documents_auto_owned_by_peers.setter
    def documents_auto_owned_by_peers(self, documents_auto_owned_by_peers):
        """Sets the documents_auto_owned_by_peers of this Permissions.


        :param documents_auto_owned_by_peers: The documents_auto_owned_by_peers of this Permissions.  # noqa: E501
        :type: bool
        """

        self._documents_auto_owned_by_peers = documents_auto_owned_by_peers

    @property
    def can_delete_owned_documents(self):
        """Gets the can_delete_owned_documents of this Permissions.  # noqa: E501


        :return: The can_delete_owned_documents of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_owned_documents

    @can_delete_owned_documents.setter
    def can_delete_owned_documents(self, can_delete_owned_documents):
        """Sets the can_delete_owned_documents of this Permissions.


        :param can_delete_owned_documents: The can_delete_owned_documents of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_owned_documents = can_delete_owned_documents

    @property
    def can_manage_shared_docs(self):
        """Gets the can_manage_shared_docs of this Permissions.  # noqa: E501


        :return: The can_manage_shared_docs of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_shared_docs

    @can_manage_shared_docs.setter
    def can_manage_shared_docs(self, can_manage_shared_docs):
        """Sets the can_manage_shared_docs of this Permissions.


        :param can_manage_shared_docs: The can_manage_shared_docs of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_shared_docs = can_manage_shared_docs

    @property
    def can_manage_form_groups(self):
        """Gets the can_manage_form_groups of this Permissions.  # noqa: E501


        :return: The can_manage_form_groups of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_form_groups

    @can_manage_form_groups.setter
    def can_manage_form_groups(self, can_manage_form_groups):
        """Sets the can_manage_form_groups of this Permissions.


        :param can_manage_form_groups: The can_manage_form_groups of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_form_groups = can_manage_form_groups

    @property
    def can_share_docs_not_owned(self):
        """Gets the can_share_docs_not_owned of this Permissions.  # noqa: E501


        :return: The can_share_docs_not_owned of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_docs_not_owned

    @can_share_docs_not_owned.setter
    def can_share_docs_not_owned(self, can_share_docs_not_owned):
        """Sets the can_share_docs_not_owned of this Permissions.


        :param can_share_docs_not_owned: The can_share_docs_not_owned of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_share_docs_not_owned = can_share_docs_not_owned

    @property
    def can_add_tasks_to_any_task_lists(self):
        """Gets the can_add_tasks_to_any_task_lists of this Permissions.  # noqa: E501


        :return: The can_add_tasks_to_any_task_lists of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_tasks_to_any_task_lists

    @can_add_tasks_to_any_task_lists.setter
    def can_add_tasks_to_any_task_lists(self, can_add_tasks_to_any_task_lists):
        """Sets the can_add_tasks_to_any_task_lists of this Permissions.


        :param can_add_tasks_to_any_task_lists: The can_add_tasks_to_any_task_lists of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_tasks_to_any_task_lists = can_add_tasks_to_any_task_lists

    @property
    def can_edit_editable_tasks(self):
        """Gets the can_edit_editable_tasks of this Permissions.  # noqa: E501


        :return: The can_edit_editable_tasks of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit_editable_tasks

    @can_edit_editable_tasks.setter
    def can_edit_editable_tasks(self, can_edit_editable_tasks):
        """Sets the can_edit_editable_tasks of this Permissions.


        :param can_edit_editable_tasks: The can_edit_editable_tasks of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_edit_editable_tasks = can_edit_editable_tasks

    @property
    def can_edit_any_tasks(self):
        """Gets the can_edit_any_tasks of this Permissions.  # noqa: E501


        :return: The can_edit_any_tasks of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit_any_tasks

    @can_edit_any_tasks.setter
    def can_edit_any_tasks(self, can_edit_any_tasks):
        """Sets the can_edit_any_tasks of this Permissions.


        :param can_edit_any_tasks: The can_edit_any_tasks of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_edit_any_tasks = can_edit_any_tasks

    @property
    def can_delete_deletable_tasks(self):
        """Gets the can_delete_deletable_tasks of this Permissions.  # noqa: E501


        :return: The can_delete_deletable_tasks of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_deletable_tasks

    @can_delete_deletable_tasks.setter
    def can_delete_deletable_tasks(self, can_delete_deletable_tasks):
        """Sets the can_delete_deletable_tasks of this Permissions.


        :param can_delete_deletable_tasks: The can_delete_deletable_tasks of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_deletable_tasks = can_delete_deletable_tasks

    @property
    def can_delete_any_tasks(self):
        """Gets the can_delete_any_tasks of this Permissions.  # noqa: E501


        :return: The can_delete_any_tasks of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_any_tasks

    @can_delete_any_tasks.setter
    def can_delete_any_tasks(self, can_delete_any_tasks):
        """Sets the can_delete_any_tasks of this Permissions.


        :param can_delete_any_tasks: The can_delete_any_tasks of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_any_tasks = can_delete_any_tasks

    @property
    def can_apply_task_list(self):
        """Gets the can_apply_task_list of this Permissions.  # noqa: E501


        :return: The can_apply_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_task_list

    @can_apply_task_list.setter
    def can_apply_task_list(self, can_apply_task_list):
        """Sets the can_apply_task_list of this Permissions.


        :param can_apply_task_list: The can_apply_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_apply_task_list = can_apply_task_list

    @property
    def can_remove_any_task_list(self):
        """Gets the can_remove_any_task_list of this Permissions.  # noqa: E501


        :return: The can_remove_any_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_any_task_list

    @can_remove_any_task_list.setter
    def can_remove_any_task_list(self, can_remove_any_task_list):
        """Sets the can_remove_any_task_list of this Permissions.


        :param can_remove_any_task_list: The can_remove_any_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_remove_any_task_list = can_remove_any_task_list

    @property
    def can_submit_task_list(self):
        """Gets the can_submit_task_list of this Permissions.  # noqa: E501


        :return: The can_submit_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_submit_task_list

    @can_submit_task_list.setter
    def can_submit_task_list(self, can_submit_task_list):
        """Sets the can_submit_task_list of this Permissions.


        :param can_submit_task_list: The can_submit_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_submit_task_list = can_submit_task_list

    @property
    def can_auto_submit_task_list(self):
        """Gets the can_auto_submit_task_list of this Permissions.  # noqa: E501


        :return: The can_auto_submit_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_auto_submit_task_list

    @can_auto_submit_task_list.setter
    def can_auto_submit_task_list(self, can_auto_submit_task_list):
        """Sets the can_auto_submit_task_list of this Permissions.


        :param can_auto_submit_task_list: The can_auto_submit_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_auto_submit_task_list = can_auto_submit_task_list

    @property
    def can_review_task_list(self):
        """Gets the can_review_task_list of this Permissions.  # noqa: E501


        :return: The can_review_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_review_task_list

    @can_review_task_list.setter
    def can_review_task_list(self, can_review_task_list):
        """Sets the can_review_task_list of this Permissions.


        :param can_review_task_list: The can_review_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_review_task_list = can_review_task_list

    @property
    def can_auto_approve_task_list(self):
        """Gets the can_auto_approve_task_list of this Permissions.  # noqa: E501


        :return: The can_auto_approve_task_list of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_auto_approve_task_list

    @can_auto_approve_task_list.setter
    def can_auto_approve_task_list(self, can_auto_approve_task_list):
        """Sets the can_auto_approve_task_list of this Permissions.


        :param can_auto_approve_task_list: The can_auto_approve_task_list of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_auto_approve_task_list = can_auto_approve_task_list

    @property
    def can_manage_task_templates_for_all_regions_all_offices(self):
        """Gets the can_manage_task_templates_for_all_regions_all_offices of this Permissions.  # noqa: E501


        :return: The can_manage_task_templates_for_all_regions_all_offices of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_task_templates_for_all_regions_all_offices

    @can_manage_task_templates_for_all_regions_all_offices.setter
    def can_manage_task_templates_for_all_regions_all_offices(self, can_manage_task_templates_for_all_regions_all_offices):
        """Sets the can_manage_task_templates_for_all_regions_all_offices of this Permissions.


        :param can_manage_task_templates_for_all_regions_all_offices: The can_manage_task_templates_for_all_regions_all_offices of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_task_templates_for_all_regions_all_offices = can_manage_task_templates_for_all_regions_all_offices

    @property
    def can_apply_room_templates(self):
        """Gets the can_apply_room_templates of this Permissions.  # noqa: E501


        :return: The can_apply_room_templates of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_room_templates

    @can_apply_room_templates.setter
    def can_apply_room_templates(self, can_apply_room_templates):
        """Sets the can_apply_room_templates of this Permissions.


        :param can_apply_room_templates: The can_apply_room_templates of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_apply_room_templates = can_apply_room_templates

    @property
    def can_add_tasks_to_rooms(self):
        """Gets the can_add_tasks_to_rooms of this Permissions.  # noqa: E501


        :return: The can_add_tasks_to_rooms of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_tasks_to_rooms

    @can_add_tasks_to_rooms.setter
    def can_add_tasks_to_rooms(self, can_add_tasks_to_rooms):
        """Sets the can_add_tasks_to_rooms of this Permissions.


        :param can_add_tasks_to_rooms: The can_add_tasks_to_rooms of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_tasks_to_rooms = can_add_tasks_to_rooms

    @property
    def can_create_and_manage_packages(self):
        """Gets the can_create_and_manage_packages of this Permissions.  # noqa: E501


        :return: The can_create_and_manage_packages of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_create_and_manage_packages

    @can_create_and_manage_packages.setter
    def can_create_and_manage_packages(self, can_create_and_manage_packages):
        """Sets the can_create_and_manage_packages of this Permissions.


        :param can_create_and_manage_packages: The can_create_and_manage_packages of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_create_and_manage_packages = can_create_and_manage_packages

    @property
    def can_add_member_and_set_role_lower_access_level(self):
        """Gets the can_add_member_and_set_role_lower_access_level of this Permissions.  # noqa: E501


        :return: The can_add_member_and_set_role_lower_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_member_and_set_role_lower_access_level

    @can_add_member_and_set_role_lower_access_level.setter
    def can_add_member_and_set_role_lower_access_level(self, can_add_member_and_set_role_lower_access_level):
        """Sets the can_add_member_and_set_role_lower_access_level of this Permissions.


        :param can_add_member_and_set_role_lower_access_level: The can_add_member_and_set_role_lower_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_member_and_set_role_lower_access_level = can_add_member_and_set_role_lower_access_level

    @property
    def can_add_member_and_set_role_same_access_level(self):
        """Gets the can_add_member_and_set_role_same_access_level of this Permissions.  # noqa: E501


        :return: The can_add_member_and_set_role_same_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_member_and_set_role_same_access_level

    @can_add_member_and_set_role_same_access_level.setter
    def can_add_member_and_set_role_same_access_level(self, can_add_member_and_set_role_same_access_level):
        """Sets the can_add_member_and_set_role_same_access_level of this Permissions.


        :param can_add_member_and_set_role_same_access_level: The can_add_member_and_set_role_same_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_add_member_and_set_role_same_access_level = can_add_member_and_set_role_same_access_level

    @property
    def can_change_member_role_lower_access_level(self):
        """Gets the can_change_member_role_lower_access_level of this Permissions.  # noqa: E501


        :return: The can_change_member_role_lower_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_change_member_role_lower_access_level

    @can_change_member_role_lower_access_level.setter
    def can_change_member_role_lower_access_level(self, can_change_member_role_lower_access_level):
        """Sets the can_change_member_role_lower_access_level of this Permissions.


        :param can_change_member_role_lower_access_level: The can_change_member_role_lower_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_change_member_role_lower_access_level = can_change_member_role_lower_access_level

    @property
    def can_change_member_role_same_access_level(self):
        """Gets the can_change_member_role_same_access_level of this Permissions.  # noqa: E501


        :return: The can_change_member_role_same_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_change_member_role_same_access_level

    @can_change_member_role_same_access_level.setter
    def can_change_member_role_same_access_level(self, can_change_member_role_same_access_level):
        """Sets the can_change_member_role_same_access_level of this Permissions.


        :param can_change_member_role_same_access_level: The can_change_member_role_same_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_change_member_role_same_access_level = can_change_member_role_same_access_level

    @property
    def can_manage_member_lower_access_level(self):
        """Gets the can_manage_member_lower_access_level of this Permissions.  # noqa: E501


        :return: The can_manage_member_lower_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_member_lower_access_level

    @can_manage_member_lower_access_level.setter
    def can_manage_member_lower_access_level(self, can_manage_member_lower_access_level):
        """Sets the can_manage_member_lower_access_level of this Permissions.


        :param can_manage_member_lower_access_level: The can_manage_member_lower_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_member_lower_access_level = can_manage_member_lower_access_level

    @property
    def can_manage_member_same_access_level(self):
        """Gets the can_manage_member_same_access_level of this Permissions.  # noqa: E501


        :return: The can_manage_member_same_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_member_same_access_level

    @can_manage_member_same_access_level.setter
    def can_manage_member_same_access_level(self, can_manage_member_same_access_level):
        """Sets the can_manage_member_same_access_level of this Permissions.


        :param can_manage_member_same_access_level: The can_manage_member_same_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_member_same_access_level = can_manage_member_same_access_level

    @property
    def can_remove_company_member_lower_access_level(self):
        """Gets the can_remove_company_member_lower_access_level of this Permissions.  # noqa: E501


        :return: The can_remove_company_member_lower_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_company_member_lower_access_level

    @can_remove_company_member_lower_access_level.setter
    def can_remove_company_member_lower_access_level(self, can_remove_company_member_lower_access_level):
        """Sets the can_remove_company_member_lower_access_level of this Permissions.


        :param can_remove_company_member_lower_access_level: The can_remove_company_member_lower_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_remove_company_member_lower_access_level = can_remove_company_member_lower_access_level

    @property
    def can_remove_company_member_same_access_level(self):
        """Gets the can_remove_company_member_same_access_level of this Permissions.  # noqa: E501


        :return: The can_remove_company_member_same_access_level of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_company_member_same_access_level

    @can_remove_company_member_same_access_level.setter
    def can_remove_company_member_same_access_level(self, can_remove_company_member_same_access_level):
        """Sets the can_remove_company_member_same_access_level of this Permissions.


        :param can_remove_company_member_same_access_level: The can_remove_company_member_same_access_level of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_remove_company_member_same_access_level = can_remove_company_member_same_access_level

    @property
    def can_manage_account(self):
        """Gets the can_manage_account of this Permissions.  # noqa: E501


        :return: The can_manage_account of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_account

    @can_manage_account.setter
    def can_manage_account(self, can_manage_account):
        """Sets the can_manage_account of this Permissions.


        :param can_manage_account: The can_manage_account of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_account = can_manage_account

    @property
    def can_manage_logo(self):
        """Gets the can_manage_logo of this Permissions.  # noqa: E501


        :return: The can_manage_logo of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_logo

    @can_manage_logo.setter
    def can_manage_logo(self, can_manage_logo):
        """Sets the can_manage_logo of this Permissions.


        :param can_manage_logo: The can_manage_logo of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_logo = can_manage_logo

    @property
    def can_manage_room_details(self):
        """Gets the can_manage_room_details of this Permissions.  # noqa: E501


        :return: The can_manage_room_details of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_room_details

    @can_manage_room_details.setter
    def can_manage_room_details(self, can_manage_room_details):
        """Sets the can_manage_room_details of this Permissions.


        :param can_manage_room_details: The can_manage_room_details of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_room_details = can_manage_room_details

    @property
    def can_manage_room_templates(self):
        """Gets the can_manage_room_templates of this Permissions.  # noqa: E501


        :return: The can_manage_room_templates of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_room_templates

    @can_manage_room_templates.setter
    def can_manage_room_templates(self, can_manage_room_templates):
        """Sets the can_manage_room_templates of this Permissions.


        :param can_manage_room_templates: The can_manage_room_templates of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_room_templates = can_manage_room_templates

    @property
    def can_manage_integration_settings(self):
        """Gets the can_manage_integration_settings of this Permissions.  # noqa: E501


        :return: The can_manage_integration_settings of this Permissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_integration_settings

    @can_manage_integration_settings.setter
    def can_manage_integration_settings(self, can_manage_integration_settings):
        """Sets the can_manage_integration_settings of this Permissions.


        :param can_manage_integration_settings: The can_manage_integration_settings of this Permissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_integration_settings = can_manage_integration_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Permissions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Permissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FormDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'form_id': 'str',
        'name': 'str',
        'created_date': 'datetime',
        'last_updated_date': 'datetime',
        'available_on_date': 'datetime',
        'owner_name': 'str',
        'version': 'str',
        'number_of_pages': 'int'
    }

    attribute_map = {
        'form_id': 'formId',
        'name': 'name',
        'created_date': 'createdDate',
        'last_updated_date': 'lastUpdatedDate',
        'available_on_date': 'availableOnDate',
        'owner_name': 'ownerName',
        'version': 'version',
        'number_of_pages': 'numberOfPages'
    }

    def __init__(self, form_id=None, name=None, created_date=None, last_updated_date=None, available_on_date=None, owner_name=None, version=None, number_of_pages=None):  # noqa: E501
        """FormDetails - a model defined in Swagger"""  # noqa: E501

        self._form_id = None
        self._name = None
        self._created_date = None
        self._last_updated_date = None
        self._available_on_date = None
        self._owner_name = None
        self._version = None
        self._number_of_pages = None
        self.discriminator = None

        if form_id is not None:
            self.form_id = form_id
        if name is not None:
            self.name = name
        if created_date is not None:
            self.created_date = created_date
        if last_updated_date is not None:
            self.last_updated_date = last_updated_date
        if available_on_date is not None:
            self.available_on_date = available_on_date
        if owner_name is not None:
            self.owner_name = owner_name
        if version is not None:
            self.version = version
        if number_of_pages is not None:
            self.number_of_pages = number_of_pages

    @property
    def form_id(self):
        """Gets the form_id of this FormDetails.  # noqa: E501


        :return: The form_id of this FormDetails.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this FormDetails.


        :param form_id: The form_id of this FormDetails.  # noqa: E501
        :type: str
        """

        self._form_id = form_id

    @property
    def name(self):
        """Gets the name of this FormDetails.  # noqa: E501


        :return: The name of this FormDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FormDetails.


        :param name: The name of this FormDetails.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def created_date(self):
        """Gets the created_date of this FormDetails.  # noqa: E501


        :return: The created_date of this FormDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this FormDetails.


        :param created_date: The created_date of this FormDetails.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def last_updated_date(self):
        """Gets the last_updated_date of this FormDetails.  # noqa: E501


        :return: The last_updated_date of this FormDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_date

    @last_updated_date.setter
    def last_updated_date(self, last_updated_date):
        """Sets the last_updated_date of this FormDetails.


        :param last_updated_date: The last_updated_date of this FormDetails.  # noqa: E501
        :type: datetime
        """

        self._last_updated_date = last_updated_date

    @property
    def available_on_date(self):
        """Gets the available_on_date of this FormDetails.  # noqa: E501


        :return: The available_on_date of this FormDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._available_on_date

    @available_on_date.setter
    def available_on_date(self, available_on_date):
        """Sets the available_on_date of this FormDetails.


        :param available_on_date: The available_on_date of this FormDetails.  # noqa: E501
        :type: datetime
        """

        self._available_on_date = available_on_date

    @property
    def owner_name(self):
        """Gets the owner_name of this FormDetails.  # noqa: E501


        :return: The owner_name of this FormDetails.  # noqa: E501
        :rtype: str
        """
        return self._owner_name

    @owner_name.setter
    def owner_name(self, owner_name):
        """Sets the owner_name of this FormDetails.


        :param owner_name: The owner_name of this FormDetails.  # noqa: E501
        :type: str
        """

        self._owner_name = owner_name

    @property
    def version(self):
        """Gets the version of this FormDetails.  # noqa: E501


        :return: The version of this FormDetails.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this FormDetails.


        :param version: The version of this FormDetails.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def number_of_pages(self):
        """Gets the number_of_pages of this FormDetails.  # noqa: E501


        :return: The number_of_pages of this FormDetails.  # noqa: E501
        :rtype: int
        """
        return self._number_of_pages

    @number_of_pages.setter
    def number_of_pages(self, number_of_pages):
        """Sets the number_of_pages of this FormDetails.


        :param number_of_pages: The number_of_pages of this FormDetails.  # noqa: E501
        :type: int
        """

        self._number_of_pages = number_of_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaskListTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_list_template_id': 'int',
        'name': 'str',
        'task_count': 'int',
        'tasks_with_documents_count': 'int'
    }

    attribute_map = {
        'task_list_template_id': 'taskListTemplateId',
        'name': 'name',
        'task_count': 'taskCount',
        'tasks_with_documents_count': 'tasksWithDocumentsCount'
    }

    def __init__(self, task_list_template_id=None, name=None, task_count=None, tasks_with_documents_count=None):  # noqa: E501
        """TaskListTemplate - a model defined in Swagger"""  # noqa: E501

        self._task_list_template_id = None
        self._name = None
        self._task_count = None
        self._tasks_with_documents_count = None
        self.discriminator = None

        if task_list_template_id is not None:
            self.task_list_template_id = task_list_template_id
        if name is not None:
            self.name = name
        if task_count is not None:
            self.task_count = task_count
        if tasks_with_documents_count is not None:
            self.tasks_with_documents_count = tasks_with_documents_count

    @property
    def task_list_template_id(self):
        """Gets the task_list_template_id of this TaskListTemplate.  # noqa: E501


        :return: The task_list_template_id of this TaskListTemplate.  # noqa: E501
        :rtype: int
        """
        return self._task_list_template_id

    @task_list_template_id.setter
    def task_list_template_id(self, task_list_template_id):
        """Sets the task_list_template_id of this TaskListTemplate.


        :param task_list_template_id: The task_list_template_id of this TaskListTemplate.  # noqa: E501
        :type: int
        """

        self._task_list_template_id = task_list_template_id

    @property
    def name(self):
        """Gets the name of this TaskListTemplate.  # noqa: E501


        :return: The name of this TaskListTemplate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskListTemplate.


        :param name: The name of this TaskListTemplate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def task_count(self):
        """Gets the task_count of this TaskListTemplate.  # noqa: E501


        :return: The task_count of this TaskListTemplate.  # noqa: E501
        :rtype: int
        """
        return self._task_count

    @task_count.setter
    def task_count(self, task_count):
        """Sets the task_count of this TaskListTemplate.


        :param task_count: The task_count of this TaskListTemplate.  # noqa: E501
        :type: int
        """

        self._task_count = task_count

    @property
    def tasks_with_documents_count(self):
        """Gets the tasks_with_documents_count of this TaskListTemplate.  # noqa: E501


        :return: The tasks_with_documents_count of this TaskListTemplate.  # noqa: E501
        :rtype: int
        """
        return self._tasks_with_documents_count

    @tasks_with_documents_count.setter
    def tasks_with_documents_count(self, tasks_with_documents_count):
        """Sets the tasks_with_documents_count of this TaskListTemplate.


        :param tasks_with_documents_count: The tasks_with_documents_count of this TaskListTemplate.  # noqa: E501
        :type: int
        """

        self._tasks_with_documents_count = tasks_with_documents_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskListTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskListTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..client.configuration import Configuration
from ..client.api_client import ApiClient


class RoomTemplatesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_room_templates(self, account_id, **kwargs):
        """
        Returns all room templates that the active user has access to
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_templates(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param int office_id: Get all room templates you have access to for this office. Response includes Company and Region level templates. If onlyAssignable is true, and no officeId is provided, user's default office is assumed.
        :param bool only_assignable: Get list of templates you have access to. Default value false.
        :param int count: Number of room templates to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :return: RoomTemplatesSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_room_templates_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_room_templates_with_http_info(account_id, **kwargs)
            return data

    def get_room_templates_with_http_info(self, account_id, **kwargs):
        """
        Returns all room templates that the active user has access to
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_templates_with_http_info(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param int office_id: Get all room templates you have access to for this office. Response includes Company and Region level templates. If onlyAssignable is true, and no officeId is provided, user's default office is assumed.
        :param bool only_assignable: Get list of templates you have access to. Default value false.
        :param int count: Number of room templates to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :return: RoomTemplatesSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'office_id', 'only_assignable', 'count', 'start_position']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_room_templates" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_room_templates`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/room_templates'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'office_id' in params:
            query_params['officeId'] = params['office_id']
        if 'only_assignable' in params:
            query_params['onlyAssignable'] = params['only_assignable']
        if 'count' in params:
            query_params['count'] = params['count']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomTemplatesSummaryList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'int',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'is_locked_out': 'bool',
        'status': 'str',
        'access_level': 'str',
        'default_office_id': 'int',
        'title_id': 'int',
        'role_id': 'int',
        'profile_image_url': 'str',
        'offices': 'list[int]',
        'regions': 'list[int]',
        'permissions': 'ClassicManagerPermissions'
    }

    attribute_map = {
        'user_id': 'userId',
        'email': 'email',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'is_locked_out': 'isLockedOut',
        'status': 'status',
        'access_level': 'accessLevel',
        'default_office_id': 'defaultOfficeId',
        'title_id': 'titleId',
        'role_id': 'roleId',
        'profile_image_url': 'profileImageUrl',
        'offices': 'offices',
        'regions': 'regions',
        'permissions': 'permissions'
    }

    def __init__(self, user_id=None, email=None, first_name=None, last_name=None, is_locked_out=None, status=None, access_level=None, default_office_id=None, title_id=None, role_id=None, profile_image_url=None, offices=None, regions=None, permissions=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501

        self._user_id = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._is_locked_out = None
        self._status = None
        self._access_level = None
        self._default_office_id = None
        self._title_id = None
        self._role_id = None
        self._profile_image_url = None
        self._offices = None
        self._regions = None
        self._permissions = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if is_locked_out is not None:
            self.is_locked_out = is_locked_out
        if status is not None:
            self.status = status
        if access_level is not None:
            self.access_level = access_level
        if default_office_id is not None:
            self.default_office_id = default_office_id
        if title_id is not None:
            self.title_id = title_id
        if role_id is not None:
            self.role_id = role_id
        if profile_image_url is not None:
            self.profile_image_url = profile_image_url
        if offices is not None:
            self.offices = offices
        if regions is not None:
            self.regions = regions
        if permissions is not None:
            self.permissions = permissions

    @property
    def user_id(self):
        """Gets the user_id of this User.  # noqa: E501


        :return: The user_id of this User.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this User.


        :param user_id: The user_id of this User.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501


        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.


        :param email: The email of this User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501


        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.


        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501


        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.


        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def is_locked_out(self):
        """Gets the is_locked_out of this User.  # noqa: E501


        :return: The is_locked_out of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_locked_out

    @is_locked_out.setter
    def is_locked_out(self, is_locked_out):
        """Sets the is_locked_out of this User.


        :param is_locked_out: The is_locked_out of this User.  # noqa: E501
        :type: bool
        """

        self._is_locked_out = is_locked_out

    @property
    def status(self):
        """Gets the status of this User.  # noqa: E501


        :return: The status of this User.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this User.


        :param status: The status of this User.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def access_level(self):
        """Gets the access_level of this User.  # noqa: E501


        :return: The access_level of this User.  # noqa: E501
        :rtype: str
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this User.


        :param access_level: The access_level of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["Contributor", "Office", "Region", "Company", "Admin"]  # noqa: E501
        if access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(access_level, allowed_values)
            )

        self._access_level = access_level

    @property
    def default_office_id(self):
        """Gets the default_office_id of this User.  # noqa: E501


        :return: The default_office_id of this User.  # noqa: E501
        :rtype: int
        """
        return self._default_office_id

    @default_office_id.setter
    def default_office_id(self, default_office_id):
        """Sets the default_office_id of this User.


        :param default_office_id: The default_office_id of this User.  # noqa: E501
        :type: int
        """

        self._default_office_id = default_office_id

    @property
    def title_id(self):
        """Gets the title_id of this User.  # noqa: E501


        :return: The title_id of this User.  # noqa: E501
        :rtype: int
        """
        return self._title_id

    @title_id.setter
    def title_id(self, title_id):
        """Sets the title_id of this User.


        :param title_id: The title_id of this User.  # noqa: E501
        :type: int
        """

        self._title_id = title_id

    @property
    def role_id(self):
        """Gets the role_id of this User.  # noqa: E501


        :return: The role_id of this User.  # noqa: E501
        :rtype: int
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this User.


        :param role_id: The role_id of this User.  # noqa: E501
        :type: int
        """

        self._role_id = role_id

    @property
    def profile_image_url(self):
        """Gets the profile_image_url of this User.  # noqa: E501


        :return: The profile_image_url of this User.  # noqa: E501
        :rtype: str
        """
        return self._profile_image_url

    @profile_image_url.setter
    def profile_image_url(self, profile_image_url):
        """Sets the profile_image_url of this User.


        :param profile_image_url: The profile_image_url of this User.  # noqa: E501
        :type: str
        """

        self._profile_image_url = profile_image_url

    @property
    def offices(self):
        """Gets the offices of this User.  # noqa: E501


        :return: The offices of this User.  # noqa: E501
        :rtype: list[int]
        """
        return self._offices

    @offices.setter
    def offices(self, offices):
        """Sets the offices of this User.


        :param offices: The offices of this User.  # noqa: E501
        :type: list[int]
        """

        self._offices = offices

    @property
    def regions(self):
        """Gets the regions of this User.  # noqa: E501


        :return: The regions of this User.  # noqa: E501
        :rtype: list[int]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """Sets the regions of this User.


        :param regions: The regions of this User.  # noqa: E501
        :type: list[int]
        """

        self._regions = regions

    @property
    def permissions(self):
        """Gets the permissions of this User.  # noqa: E501


        :return: The permissions of this User.  # noqa: E501
        :rtype: ClassicManagerPermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this User.


        :param permissions: The permissions of this User.  # noqa: E501
        :type: ClassicManagerPermissions
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RoomDocument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_id': 'int',
        'name': 'str',
        'owner_id': 'int',
        'size': 'int',
        'folder_id': 'int',
        'created_date': 'datetime',
        'is_signed': 'bool',
        'docu_sign_form_id': 'str'
    }

    attribute_map = {
        'document_id': 'documentId',
        'name': 'name',
        'owner_id': 'ownerId',
        'size': 'size',
        'folder_id': 'folderId',
        'created_date': 'createdDate',
        'is_signed': 'isSigned',
        'docu_sign_form_id': 'docuSignFormId'
    }

    def __init__(self, document_id=None, name=None, owner_id=None, size=None, folder_id=None, created_date=None, is_signed=None, docu_sign_form_id=None):  # noqa: E501
        """RoomDocument - a model defined in Swagger"""  # noqa: E501

        self._document_id = None
        self._name = None
        self._owner_id = None
        self._size = None
        self._folder_id = None
        self._created_date = None
        self._is_signed = None
        self._docu_sign_form_id = None
        self.discriminator = None

        if document_id is not None:
            self.document_id = document_id
        if name is not None:
            self.name = name
        if owner_id is not None:
            self.owner_id = owner_id
        if size is not None:
            self.size = size
        if folder_id is not None:
            self.folder_id = folder_id
        if created_date is not None:
            self.created_date = created_date
        if is_signed is not None:
            self.is_signed = is_signed
        if docu_sign_form_id is not None:
            self.docu_sign_form_id = docu_sign_form_id

    @property
    def document_id(self):
        """Gets the document_id of this RoomDocument.  # noqa: E501


        :return: The document_id of this RoomDocument.  # noqa: E501
        :rtype: int
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this RoomDocument.


        :param document_id: The document_id of this RoomDocument.  # noqa: E501
        :type: int
        """

        self._document_id = document_id

    @property
    def name(self):
        """Gets the name of this RoomDocument.  # noqa: E501


        :return: The name of this RoomDocument.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RoomDocument.


        :param name: The name of this RoomDocument.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this RoomDocument.  # noqa: E501


        :return: The owner_id of this RoomDocument.  # noqa: E501
        :rtype: int
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this RoomDocument.


        :param owner_id: The owner_id of this RoomDocument.  # noqa: E501
        :type: int
        """

        self._owner_id = owner_id

    @property
    def size(self):
        """Gets the size of this RoomDocument.  # noqa: E501


        :return: The size of this RoomDocument.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this RoomDocument.


        :param size: The size of this RoomDocument.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def folder_id(self):
        """Gets the folder_id of this RoomDocument.  # noqa: E501


        :return: The folder_id of this RoomDocument.  # noqa: E501
        :rtype: int
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this RoomDocument.


        :param folder_id: The folder_id of this RoomDocument.  # noqa: E501
        :type: int
        """

        self._folder_id = folder_id

    @property
    def created_date(self):
        """Gets the created_date of this RoomDocument.  # noqa: E501


        :return: The created_date of this RoomDocument.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this RoomDocument.


        :param created_date: The created_date of this RoomDocument.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def is_signed(self):
        """Gets the is_signed of this RoomDocument.  # noqa: E501


        :return: The is_signed of this RoomDocument.  # noqa: E501
        :rtype: bool
        """
        return self._is_signed

    @is_signed.setter
    def is_signed(self, is_signed):
        """Sets the is_signed of this RoomDocument.


        :param is_signed: The is_signed of this RoomDocument.  # noqa: E501
        :type: bool
        """

        self._is_signed = is_signed

    @property
    def docu_sign_form_id(self):
        """Gets the docu_sign_form_id of this RoomDocument.  # noqa: E501


        :return: The docu_sign_form_id of this RoomDocument.  # noqa: E501
        :rtype: str
        """
        return self._docu_sign_form_id

    @docu_sign_form_id.setter
    def docu_sign_form_id(self, docu_sign_form_id):
        """Sets the docu_sign_form_id of this RoomDocument.


        :param docu_sign_form_id: The docu_sign_form_id of this RoomDocument.  # noqa: E501
        :type: str
        """

        self._docu_sign_form_id = docu_sign_form_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RoomDocument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomDocument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AccountSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_id': 'int',
        'name': 'str',
        'company_version': 'str',
        'docu_sign_account_guid': 'str',
        'default_field_set_id': 'str',
        'require_office_library_assignments': 'bool'
    }

    attribute_map = {
        'company_id': 'companyId',
        'name': 'name',
        'company_version': 'companyVersion',
        'docu_sign_account_guid': 'docuSignAccountGuid',
        'default_field_set_id': 'defaultFieldSetId',
        'require_office_library_assignments': 'requireOfficeLibraryAssignments'
    }

    def __init__(self, company_id=None, name=None, company_version=None, docu_sign_account_guid=None, default_field_set_id=None, require_office_library_assignments=None):  # noqa: E501
        """AccountSummary - a model defined in Swagger"""  # noqa: E501

        self._company_id = None
        self._name = None
        self._company_version = None
        self._docu_sign_account_guid = None
        self._default_field_set_id = None
        self._require_office_library_assignments = None
        self.discriminator = None

        if company_id is not None:
            self.company_id = company_id
        if name is not None:
            self.name = name
        if company_version is not None:
            self.company_version = company_version
        if docu_sign_account_guid is not None:
            self.docu_sign_account_guid = docu_sign_account_guid
        if default_field_set_id is not None:
            self.default_field_set_id = default_field_set_id
        if require_office_library_assignments is not None:
            self.require_office_library_assignments = require_office_library_assignments

    @property
    def company_id(self):
        """Gets the company_id of this AccountSummary.  # noqa: E501


        :return: The company_id of this AccountSummary.  # noqa: E501
        :rtype: int
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this AccountSummary.


        :param company_id: The company_id of this AccountSummary.  # noqa: E501
        :type: int
        """

        self._company_id = company_id

    @property
    def name(self):
        """Gets the name of this AccountSummary.  # noqa: E501


        :return: The name of this AccountSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountSummary.


        :param name: The name of this AccountSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def company_version(self):
        """Gets the company_version of this AccountSummary.  # noqa: E501


        :return: The company_version of this AccountSummary.  # noqa: E501
        :rtype: str
        """
        return self._company_version

    @company_version.setter
    def company_version(self, company_version):
        """Sets the company_version of this AccountSummary.


        :param company_version: The company_version of this AccountSummary.  # noqa: E501
        :type: str
        """
        allowed_values = ["v5", "v6"]  # noqa: E501
        if company_version not in allowed_values:
            raise ValueError(
                "Invalid value for `company_version` ({0}), must be one of {1}"  # noqa: E501
                .format(company_version, allowed_values)
            )

        self._company_version = company_version

    @property
    def docu_sign_account_guid(self):
        """Gets the docu_sign_account_guid of this AccountSummary.  # noqa: E501


        :return: The docu_sign_account_guid of this AccountSummary.  # noqa: E501
        :rtype: str
        """
        return self._docu_sign_account_guid

    @docu_sign_account_guid.setter
    def docu_sign_account_guid(self, docu_sign_account_guid):
        """Sets the docu_sign_account_guid of this AccountSummary.


        :param docu_sign_account_guid: The docu_sign_account_guid of this AccountSummary.  # noqa: E501
        :type: str
        """

        self._docu_sign_account_guid = docu_sign_account_guid

    @property
    def default_field_set_id(self):
        """Gets the default_field_set_id of this AccountSummary.  # noqa: E501


        :return: The default_field_set_id of this AccountSummary.  # noqa: E501
        :rtype: str
        """
        return self._default_field_set_id

    @default_field_set_id.setter
    def default_field_set_id(self, default_field_set_id):
        """Sets the default_field_set_id of this AccountSummary.


        :param default_field_set_id: The default_field_set_id of this AccountSummary.  # noqa: E501
        :type: str
        """

        self._default_field_set_id = default_field_set_id

    @property
    def require_office_library_assignments(self):
        """Gets the require_office_library_assignments of this AccountSummary.  # noqa: E501


        :return: The require_office_library_assignments of this AccountSummary.  # noqa: E501
        :rtype: bool
        """
        return self._require_office_library_assignments

    @require_office_library_assignments.setter
    def require_office_library_assignments(self, require_office_library_assignments):
        """Sets the require_office_library_assignments of this AccountSummary.


        :param require_office_library_assignments: The require_office_library_assignments of this AccountSummary.  # noqa: E501
        :type: bool
        """

        self._require_office_library_assignments = require_office_library_assignments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from .apis.accounts_api import AccountsApi
from .apis.activity_types_api import ActivityTypesApi
from .apis.closing_statuses_api import ClosingStatusesApi
from .apis.contact_sides_api import ContactSidesApi
from .apis.countries_api import CountriesApi
from .apis.currencies_api import CurrenciesApi
from .apis.documents_api import DocumentsApi
from .apis.e_sign_permission_profiles_api import ESignPermissionProfilesApi
from .apis.external_form_fill_sessions_api import ExternalFormFillSessionsApi
from .apis.fields_api import FieldsApi
from .apis.financing_types_api import FinancingTypesApi
from .apis.form_details_api import FormDetailsApi
from .apis.form_groups_api import FormGroupsApi
from .apis.form_libraries_api import FormLibrariesApi
from .apis.offices_api import OfficesApi
from .apis.origins_of_leads_api import OriginsOfLeadsApi
from .apis.property_types_api import PropertyTypesApi
from .apis.regions_api import RegionsApi
from .apis.roles_api import RolesApi
from .apis.room_contact_types_api import RoomContactTypesApi
from .apis.room_folders_api import RoomFoldersApi
from .apis.room_templates_api import RoomTemplatesApi
from .apis.rooms_api import RoomsApi
from .apis.seller_decision_types_api import SellerDecisionTypesApi
from .apis.special_circumstance_types_api import SpecialCircumstanceTypesApi
from .apis.states_api import StatesApi
from .apis.task_date_types_api import TaskDateTypesApi
from .apis.task_list_templates_api import TaskListTemplatesApi
from .apis.task_lists_api import TaskListsApi
from .apis.task_responsibility_types_api import TaskResponsibilityTypesApi
from .apis.task_statuses_api import TaskStatusesApi
from .apis.time_zones_api import TimeZonesApi
from .apis.transaction_sides_api import TransactionSidesApi
from .apis.users_api import UsersApi

# import ApiClient
from .client.api_client import ApiClient
from .client.configuration import Configuration
from .client.api_exception import ApiException

# import models into sdk package
from .models.account_summary import AccountSummary
from .models.activity_type import ActivityType
from .models.api_error import ApiError
from .models.assignable_roles import AssignableRoles
from .models.classic_admin_to_invite import ClassicAdminToInvite
from .models.classic_agent_to_invite import ClassicAgentToInvite
from .models.classic_manager_permissions import ClassicManagerPermissions
from .models.classic_manager_to_invite import ClassicManagerToInvite
from .models.closing_status import ClosingStatus
from .models.contact_side import ContactSide
from .models.country import Country
from .models.currency import Currency
from .models.custom_data import CustomData
from .models.depends_on import DependsOn
from .models.designated_office import DesignatedOffice
from .models.designated_region import DesignatedRegion
from .models.document import Document
from .models.document_user import DocumentUser
from .models.document_user_for_create import DocumentUserForCreate
from .models.e_sign_account_role_settings import ESignAccountRoleSettings
from .models.e_sign_permission_profile import ESignPermissionProfile
from .models.e_sign_permission_profile_list import ESignPermissionProfileList
from .models.external_form_fill_session import ExternalFormFillSession
from .models.external_form_fill_session_for_create import ExternalFormFillSessionForCreate
from .models.field import Field
from .models.field_configuration import FieldConfiguration
from .models.field_data import FieldData
from .models.field_data_for_create import FieldDataForCreate
from .models.field_data_for_update import FieldDataForUpdate
from .models.field_set import FieldSet
from .models.financing_type import FinancingType
from .models.form_details import FormDetails
from .models.form_for_add import FormForAdd
from .models.form_group_summary import FormGroupSummary
from .models.form_group_summary_list import FormGroupSummaryList
from .models.form_library_summary import FormLibrarySummary
from .models.form_library_summary_list import FormLibrarySummaryList
from .models.form_summary import FormSummary
from .models.form_summary_list import FormSummaryList
from .models.global_activity_types import GlobalActivityTypes
from .models.global_closing_statuses import GlobalClosingStatuses
from .models.global_contact_sides import GlobalContactSides
from .models.global_countries import GlobalCountries
from .models.global_currencies import GlobalCurrencies
from .models.global_financing_types import GlobalFinancingTypes
from .models.global_origins_of_leads import GlobalOriginsOfLeads
from .models.global_property_types import GlobalPropertyTypes
from .models.global_room_contact_types import GlobalRoomContactTypes
from .models.global_seller_decision_types import GlobalSellerDecisionTypes
from .models.global_special_circumstance_types import GlobalSpecialCircumstanceTypes
from .models.global_states import GlobalStates
from .models.global_task_date_types import GlobalTaskDateTypes
from .models.global_task_responsibility_types import GlobalTaskResponsibilityTypes
from .models.global_task_statuses import GlobalTaskStatuses
from .models.global_time_zones import GlobalTimeZones
from .models.global_transaction_sides import GlobalTransactionSides
from .models.locked_out_details import LockedOutDetails
from .models.nullable_field_data import NullableFieldData
from .models.nullable_permissions import NullablePermissions
from .models.office import Office
from .models.office_for_create import OfficeForCreate
from .models.office_reference_count import OfficeReferenceCount
from .models.office_reference_count_list import OfficeReferenceCountList
from .models.office_summary import OfficeSummary
from .models.office_summary_list import OfficeSummaryList
from .models.origin_of_lead import OriginOfLead
from .models.permissions import Permissions
from .models.property_type import PropertyType
from .models.region import Region
from .models.region_reference_count import RegionReferenceCount
from .models.region_reference_count_list import RegionReferenceCountList
from .models.region_summary import RegionSummary
from .models.region_summary_list import RegionSummaryList
from .models.role import Role
from .models.role_for_create import RoleForCreate
from .models.role_for_update import RoleForUpdate
from .models.role_summary import RoleSummary
from .models.role_summary_list import RoleSummaryList
from .models.room import Room
from .models.room_contact_type import RoomContactType
from .models.room_document import RoomDocument
from .models.room_document_list import RoomDocumentList
from .models.room_folder import RoomFolder
from .models.room_folder_list import RoomFolderList
from .models.room_for_create import RoomForCreate
from .models.room_invite import RoomInvite
from .models.room_invite_response import RoomInviteResponse
from .models.room_picture import RoomPicture
from .models.room_summary import RoomSummary
from .models.room_summary_list import RoomSummaryList
from .models.room_template import RoomTemplate
from .models.room_templates_summary_list import RoomTemplatesSummaryList
from .models.room_user import RoomUser
from .models.room_user_for_update import RoomUserForUpdate
from .models.room_user_removal_detail import RoomUserRemovalDetail
from .models.room_user_summary import RoomUserSummary
from .models.room_users_result import RoomUsersResult
from .models.select_list_field_option import SelectListFieldOption
from .models.seller_decision_type import SellerDecisionType
from .models.special_circumstance_type import SpecialCircumstanceType
from .models.state import State
from .models.task_date_type import TaskDateType
from .models.task_list import TaskList
from .models.task_list_for_create import TaskListForCreate
from .models.task_list_summary import TaskListSummary
from .models.task_list_summary_list import TaskListSummaryList
from .models.task_list_template import TaskListTemplate
from .models.task_list_template_list import TaskListTemplateList
from .models.task_responsibility_type import TaskResponsibilityType
from .models.task_status import TaskStatus
from .models.task_summary import TaskSummary
from .models.time_zone import TimeZone
from .models.transaction_side import TransactionSide
from .models.user import User
from .models.user_for_update import UserForUpdate
from .models.user_summary import UserSummary
from .models.user_summary_list import UserSummaryList
from .models.user_to_invite import UserToInvite

configuration = Configuration()


# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UserSummaryList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_summaries': 'list[UserSummary]',
        'result_set_size': 'int',
        'start_position': 'int',
        'end_position': 'int',
        'next_uri': 'str',
        'prior_uri': 'str'
    }

    attribute_map = {
        'user_summaries': 'userSummaries',
        'result_set_size': 'resultSetSize',
        'start_position': 'startPosition',
        'end_position': 'endPosition',
        'next_uri': 'nextUri',
        'prior_uri': 'priorUri'
    }

    def __init__(self, user_summaries=None, result_set_size=None, start_position=None, end_position=None, next_uri=None, prior_uri=None):  # noqa: E501
        """UserSummaryList - a model defined in Swagger"""  # noqa: E501

        self._user_summaries = None
        self._result_set_size = None
        self._start_position = None
        self._end_position = None
        self._next_uri = None
        self._prior_uri = None
        self.discriminator = None

        if user_summaries is not None:
            self.user_summaries = user_summaries
        if result_set_size is not None:
            self.result_set_size = result_set_size
        if start_position is not None:
            self.start_position = start_position
        if end_position is not None:
            self.end_position = end_position
        if next_uri is not None:
            self.next_uri = next_uri
        if prior_uri is not None:
            self.prior_uri = prior_uri

    @property
    def user_summaries(self):
        """Gets the user_summaries of this UserSummaryList.  # noqa: E501


        :return: The user_summaries of this UserSummaryList.  # noqa: E501
        :rtype: list[UserSummary]
        """
        return self._user_summaries

    @user_summaries.setter
    def user_summaries(self, user_summaries):
        """Sets the user_summaries of this UserSummaryList.


        :param user_summaries: The user_summaries of this UserSummaryList.  # noqa: E501
        :type: list[UserSummary]
        """

        self._user_summaries = user_summaries

    @property
    def result_set_size(self):
        """Gets the result_set_size of this UserSummaryList.  # noqa: E501


        :return: The result_set_size of this UserSummaryList.  # noqa: E501
        :rtype: int
        """
        return self._result_set_size

    @result_set_size.setter
    def result_set_size(self, result_set_size):
        """Sets the result_set_size of this UserSummaryList.


        :param result_set_size: The result_set_size of this UserSummaryList.  # noqa: E501
        :type: int
        """

        self._result_set_size = result_set_size

    @property
    def start_position(self):
        """Gets the start_position of this UserSummaryList.  # noqa: E501


        :return: The start_position of this UserSummaryList.  # noqa: E501
        :rtype: int
        """
        return self._start_position

    @start_position.setter
    def start_position(self, start_position):
        """Sets the start_position of this UserSummaryList.


        :param start_position: The start_position of this UserSummaryList.  # noqa: E501
        :type: int
        """

        self._start_position = start_position

    @property
    def end_position(self):
        """Gets the end_position of this UserSummaryList.  # noqa: E501


        :return: The end_position of this UserSummaryList.  # noqa: E501
        :rtype: int
        """
        return self._end_position

    @end_position.setter
    def end_position(self, end_position):
        """Sets the end_position of this UserSummaryList.


        :param end_position: The end_position of this UserSummaryList.  # noqa: E501
        :type: int
        """

        self._end_position = end_position

    @property
    def next_uri(self):
        """Gets the next_uri of this UserSummaryList.  # noqa: E501


        :return: The next_uri of this UserSummaryList.  # noqa: E501
        :rtype: str
        """
        return self._next_uri

    @next_uri.setter
    def next_uri(self, next_uri):
        """Sets the next_uri of this UserSummaryList.


        :param next_uri: The next_uri of this UserSummaryList.  # noqa: E501
        :type: str
        """

        self._next_uri = next_uri

    @property
    def prior_uri(self):
        """Gets the prior_uri of this UserSummaryList.  # noqa: E501


        :return: The prior_uri of this UserSummaryList.  # noqa: E501
        :rtype: str
        """
        return self._prior_uri

    @prior_uri.setter
    def prior_uri(self, prior_uri):
        """Sets the prior_uri of this UserSummaryList.


        :param prior_uri: The prior_uri of this UserSummaryList.  # noqa: E501
        :type: str
        """

        self._prior_uri = prior_uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserSummaryList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSummaryList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
